@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875.  */
+/* A Bison parser, made by GNU Bison 2.1.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -36,6 +36,9 @@
 /* Identify Bison output.  */
 #define YYBISON 1
 
+/* Bison version.  */
+#define YYBISON_VERSION "2.1"
+
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
 
@@ -62,6 +65,7 @@
      QUOTED_NONWSEQ_STRING = 264
    };
 #endif
+/* Tokens.  */
 #define LEFT_BRACKET 258
 #define RIGHT_BRACKET 259
 #define EQUAL 260
@@ -117,13 +121,18 @@ static char *header_section = NULL; /* start with no header section */
 # define YYERROR_VERBOSE 0
 #endif
 
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 73 "conf_parse.y"
 typedef union YYSTYPE {
 char *strtype;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 126 "conf_parse.c"
+/* Line 196 of yacc.c.  */
+#line 136 "conf_parse.c"
 # define conf_stype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -134,22 +143,48 @@ char *strtype;
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 138 "conf_parse.c"
+/* Line 219 of yacc.c.  */
+#line 148 "conf_parse.c"
+
+#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
+# define YYSIZE_T __SIZE_TYPE__
+#endif
+#if ! defined (YYSIZE_T) && defined (size_t)
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T) && (defined (__STDC__) || defined (__cplusplus))
+# include <stddef.h> /* INFRINGES ON USER NAME SPACE */
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T)
+# define YYSIZE_T unsigned int
+#endif
+
+#ifndef YY_
+# if YYENABLE_NLS
+#  if ENABLE_NLS
+#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
+#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#  endif
+# endif
+# ifndef YY_
+#  define YY_(msgid) msgid
+# endif
+#endif
 
 #if ! defined (conf_overflow) || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# if YYSTACK_USE_ALLOCA
-#  define YYSTACK_ALLOC alloca
-# else
-#  ifndef YYSTACK_USE_ALLOCA
-#   if defined (alloca) || defined (_ALLOCA_H)
-#    define YYSTACK_ALLOC alloca
+# ifdef YYSTACK_USE_ALLOCA
+#  if YYSTACK_USE_ALLOCA
+#   ifdef __GNUC__
+#    define YYSTACK_ALLOC __builtin_alloca
 #   else
-#    ifdef __GNUC__
-#     define YYSTACK_ALLOC __builtin_alloca
+#    define YYSTACK_ALLOC alloca
+#    if defined (__STDC__) || defined (__cplusplus)
+#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+#     define YYINCLUDED_STDLIB_H
 #    endif
 #   endif
 #  endif
@@ -158,25 +193,51 @@ char *strtype;
 # ifdef YYSTACK_ALLOC
    /* Pacify GCC's `empty if-body' warning. */
 #  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+    /* The OS might guarantee only one guard page at the bottom of the stack,
+       and a page size can be as small as 4096 bytes.  So we cannot safely
+       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
+       to allow for a few compiler-allocated temporary stack slots.  */
+#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2005 */
+#  endif
 # else
-#  if defined (__STDC__) || defined (__cplusplus)
-#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#   define YYSIZE_T size_t
+#  define YYSTACK_ALLOC YYMALLOC
+#  define YYSTACK_FREE YYFREE
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+#   define YYSTACK_ALLOC_MAXIMUM ((YYSIZE_T) -1)
+#  endif
+#  ifdef __cplusplus
+extern "C" {
+#  endif
+#  ifndef YYMALLOC
+#   define YYMALLOC malloc
+#   if (! defined (malloc) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifndef YYFREE
+#   define YYFREE free
+#   if (! defined (free) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void free (void *); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifdef __cplusplus
+}
 #  endif
-#  define YYSTACK_ALLOC malloc
-#  define YYSTACK_FREE free
 # endif
 #endif /* ! defined (conf_overflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (conf_overflow) \
      && (! defined (__cplusplus) \
-	 || (YYSTYPE_IS_TRIVIAL)))
+	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union conf_alloc
 {
-  short conf_ss;
+  short int conf_ss;
   YYSTYPE conf_vs;
   };
 
@@ -186,20 +247,20 @@ union conf_alloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
+     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if 1 < __GNUC__
+#  if defined (__GNUC__) && 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
 #   define YYCOPY(To, From, Count)		\
       do					\
 	{					\
-	  register YYSIZE_T conf_i;		\
+	  YYSIZE_T conf_i;				\
 	  for (conf_i = 0; conf_i < (Count); conf_i++)	\
 	    (To)[conf_i] = (From)[conf_i];		\
 	}					\
@@ -228,7 +289,7 @@ union conf_alloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char conf_signed_char;
 #else
-   typedef short conf_signed_char;
+   typedef short int conf_signed_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -249,7 +310,7 @@ union conf_alloc
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   264
 
-#define YYTRANSLATE(YYX) 						\
+#define YYTRANSLATE(YYX)						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? conf_translate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
@@ -312,22 +373,22 @@ static const unsigned char conf_rline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE
-/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
+#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const conf_tname[] =
 {
-  "$end", "error", "$undefined", "LEFT_BRACKET", "RIGHT_BRACKET", "EQUAL", 
-  "NEWLINE", "NONWS_STRING", "NONWSEQ_STRING", "QUOTED_NONWSEQ_STRING", 
-  "$accept", "file", "@1", "@2", "newlines", "map_sections", 
-  "map_section", "sec_header", "kv_pairs", "kv_pair", 0
+  "$end", "error", "$undefined", "LEFT_BRACKET", "RIGHT_BRACKET", "EQUAL",
+  "NEWLINE", "NONWS_STRING", "NONWSEQ_STRING", "QUOTED_NONWSEQ_STRING",
+  "$accept", "file", "@1", "@2", "newlines", "map_sections", "map_section",
+  "sec_header", "kv_pairs", "kv_pair", 0
 };
 #endif
 
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short conf_toknum[] =
+static const unsigned short int conf_toknum[] =
 {
        0,   256,   257,   258,   259,   260,   261,   262,   263,   264
 };
@@ -407,22 +468,6 @@ static const unsigned char conf_stos[] =
        5,    18,     6,     7,     8,     9,     6,     6,     6
 };
 
-#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
-# define YYSIZE_T __SIZE_TYPE__
-#endif
-#if ! defined (YYSIZE_T) && defined (size_t)
-# define YYSIZE_T size_t
-#endif
-#if ! defined (YYSIZE_T)
-# if defined (__STDC__) || defined (__cplusplus)
-#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
-#  define YYSIZE_T size_t
-# endif
-#endif
-#if ! defined (YYSIZE_T)
-# define YYSIZE_T unsigned int
-#endif
-
 #define conf_errok		(conf_errstatus = 0)
 #define conf_clearin	(conf_char = YYEMPTY)
 #define YYEMPTY		(-2)
@@ -430,7 +475,8 @@ static const unsigned char conf_stos[] =
 
 #define YYACCEPT	goto conf_acceptlab
 #define YYABORT		goto conf_abortlab
-#define YYERROR		goto conf_errlab1
+#define YYERROR		goto conf_errorlab
+
 
 /* Like YYERROR except do call conf_error.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
@@ -451,26 +497,59 @@ do								\
       goto conf_backup;						\
     }								\
   else								\
-    { 								\
-      conf_error ("syntax error: cannot back up");\
+    {								\
+      conf_error (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)         \
-  Current.first_line   = Rhs[1].first_line;      \
-  Current.first_column = Rhs[1].first_column;    \
-  Current.last_line    = Rhs[N].last_line;       \
-  Current.last_column  = Rhs[N].last_column;
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `conf_lex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -493,36 +572,30 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (conf_debug)					\
-    conf_symprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (conf_debug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
-      conf_symprint (stderr, 					\
-                  Token, Value);	\
+      conf_symprint (stderr,					\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
 
 /*------------------------------------------------------------------.
 | conf__stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (cinluded).                                                   |
+| TOP (included).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-conf__stack_print (short *bottom, short *top)
+conf__stack_print (short int *bottom, short int *top)
 #else
 static void
 conf__stack_print (bottom, top)
-    short *bottom;
-    short *top;
+    short int *bottom;
+    short int *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -552,13 +625,13 @@ conf__reduce_print (conf_rule)
 #endif
 {
   int conf_i;
-  unsigned int conf_lineno = conf_rline[conf_rule];
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
-             conf_rule - 1, conf_lineno);
+  unsigned long int conf_lno = conf_rline[conf_rule];
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu), ",
+             conf_rule - 1, conf_lno);
   /* Print the symbols being reduced, and their result.  */
   for (conf_i = conf_prhs[conf_rule]; 0 <= conf_rhs[conf_i]; conf_i++)
-    YYFPRINTF (stderr, "%s ", conf_tname [conf_rhs[conf_i]]);
-  YYFPRINTF (stderr, "-> %s\n", conf_tname [conf_r1[conf_rule]]);
+    YYFPRINTF (stderr, "%s ", conf_tname[conf_rhs[conf_i]]);
+  YYFPRINTF (stderr, "-> %s\n", conf_tname[conf_r1[conf_rule]]);
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
@@ -572,8 +645,7 @@ do {					\
 int conf_debug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -588,13 +660,9 @@ int conf_debug;
    if the built-in stack extension method is used).
 
    Do not make this value too large; the results are undefined if
-   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
+   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -616,7 +684,7 @@ conf_strlen (conf_str)
      const char *conf_str;
 #   endif
 {
-  register const char *conf_s = conf_str;
+  const char *conf_s = conf_str;
 
   while (*conf_s++ != '\0')
     continue;
@@ -641,8 +709,8 @@ conf_stpcpy (conf_dest, conf_src)
      const char *conf_src;
 #   endif
 {
-  register char *conf_d = conf_dest;
-  register const char *conf_s = conf_src;
+  char *conf_d = conf_dest;
+  const char *conf_s = conf_src;
 
   while ((*conf_d++ = *conf_s++) != '\0')
     continue;
@@ -652,7 +720,55 @@ conf_stpcpy (conf_dest, conf_src)
 #  endif
 # endif
 
-#endif /* !YYERROR_VERBOSE */
+# ifndef conf_tnamerr
+/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
+   quotes and backslashes, so that it's suitable for conf_error.  The
+   heuristic is that double-quoting is unnecessary unless the string
+   contains an apostrophe, a comma, or backslash (other than
+   backslash-backslash).  YYSTR is taken from conf_tname.  If YYRES is
+   null, do not copy; instead, return the length of what the result
+   would have been.  */
+static YYSIZE_T
+conf_tnamerr (char *conf_res, const char *conf_str)
+{
+  if (*conf_str == '"')
+    {
+      size_t conf_n = 0;
+      char const *conf_p = conf_str;
+
+      for (;;)
+	switch (*++conf_p)
+	  {
+	  case '\'':
+	  case ',':
+	    goto do_not_strip_quotes;
+
+	  case '\\':
+	    if (*++conf_p != '\\')
+	      goto do_not_strip_quotes;
+	    /* Fall through.  */
+	  default:
+	    if (conf_res)
+	      conf_res[conf_n] = *conf_p;
+	    conf_n++;
+	    break;
+
+	  case '"':
+	    if (conf_res)
+	      conf_res[conf_n] = '\0';
+	    return conf_n;
+	  }
+    do_not_strip_quotes: ;
+    }
+
+  if (! conf_res)
+    return conf_strlen (conf_str);
+
+  return conf_stpcpy (conf_res, conf_str) - conf_res;
+}
+# endif
+
+#endif /* YYERROR_VERBOSE */
 
 
 
@@ -676,15 +792,15 @@ conf_symprint (conf_output, conf_type, conf_valuep)
   (void) conf_valuep;
 
   if (conf_type < YYNTOKENS)
-    {
-      YYFPRINTF (conf_output, "token %s (", conf_tname[conf_type]);
-# ifdef YYPRINT
-      YYPRINT (conf_output, conf_toknum[conf_type], *conf_valuep);
-# endif
-    }
+    YYFPRINTF (conf_output, "token %s (", conf_tname[conf_type]);
   else
     YYFPRINTF (conf_output, "nterm %s (", conf_tname[conf_type]);
 
+
+# ifdef YYPRINT
+  if (conf_type < YYNTOKENS)
+    YYPRINT (conf_output, conf_toknum[conf_type], *conf_valuep);
+# endif
   switch (conf_type)
     {
       default:
@@ -700,10 +816,11 @@ conf_symprint (conf_output, conf_type, conf_valuep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-conf_destruct (int conf_type, YYSTYPE *conf_valuep)
+conf_destruct (const char *conf_msg, int conf_type, YYSTYPE *conf_valuep)
 #else
 static void
-conf_destruct (conf_type, conf_valuep)
+conf_destruct (conf_msg, conf_type, conf_valuep)
+    const char *conf_msg;
     int conf_type;
     YYSTYPE *conf_valuep;
 #endif
@@ -711,6 +828,10 @@ conf_destruct (conf_type, conf_valuep)
   /* Pacify ``unused variable'' warnings.  */
   (void) conf_valuep;
 
+  if (!conf_msg)
+    conf_msg = "Deleting";
+  YY_SYMBOL_PRINT (conf_msg, conf_type, conf_valuep, conf_locationp);
+
   switch (conf_type)
     {
 
@@ -738,10 +859,10 @@ int conf_parse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int conf_char;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE conf_lval;
 
 /* Number of syntax errors so far.  */
@@ -767,17 +888,17 @@ conf_parse (void)
 #else
 int
 conf_parse ()
-
+    ;
 #endif
 #endif
 {
   
-  register int conf_state;
-  register int conf_n;
+  int conf_state;
+  int conf_n;
   int conf_result;
   /* Number of tokens to shift before error messages enabled.  */
   int conf_errstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int conf_token = 0;
 
   /* Three stacks and their tools:
@@ -789,14 +910,14 @@ conf_parse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short	conf_ssa[YYINITDEPTH];
-  short *conf_ss = conf_ssa;
-  register short *conf_ssp;
+  short int conf_ssa[YYINITDEPTH];
+  short int *conf_ss = conf_ssa;
+  short int *conf_ssp;
 
   /* The semantic value stack.  */
   YYSTYPE conf_vsa[YYINITDEPTH];
   YYSTYPE *conf_vs = conf_vsa;
-  register YYSTYPE *conf_vsp;
+  YYSTYPE *conf_vsp;
 
 
 
@@ -853,14 +974,14 @@ conf_parse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *conf_vs1 = conf_vs;
-	short *conf_ss1 = conf_ss;
+	short int *conf_ss1 = conf_ss;
 
 
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
 	   be undefined if conf_overflow is a macro.  */
-	conf_overflow ("parser stack overflow",
+	conf_overflow (YY_("memory exhausted"),
 		    &conf_ss1, conf_size * sizeof (*conf_ssp),
 		    &conf_vs1, conf_size * sizeof (*conf_vsp),
 
@@ -871,21 +992,21 @@ conf_parse ()
       }
 #else /* no conf_overflow */
 # ifndef YYSTACK_RELOCATE
-      goto conf_overflowlab;
+      goto conf_exhaustedlab;
 # else
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= conf_stacksize)
-	goto conf_overflowlab;
+	goto conf_exhaustedlab;
       conf_stacksize *= 2;
       if (YYMAXDEPTH < conf_stacksize)
 	conf_stacksize = YYMAXDEPTH;
 
       {
-	short *conf_ss1 = conf_ss;
+	short int *conf_ss1 = conf_ss;
 	union conf_alloc *conf_ptr =
 	  (union conf_alloc *) YYSTACK_ALLOC (YYSTACK_BYTES (conf_stacksize));
 	if (! conf_ptr)
-	  goto conf_overflowlab;
+	  goto conf_exhaustedlab;
 	YYSTACK_RELOCATE (conf_ss);
 	YYSTACK_RELOCATE (conf_vs);
 
@@ -917,18 +1038,18 @@ conf_parse ()
 conf_backup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* conf_resume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   conf_n = conf_pact[conf_state];
   if (conf_n == YYPACT_NINF)
     goto conf_default;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (conf_char == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -943,7 +1064,7 @@ conf_backup:
   else
     {
       conf_token = YYTRANSLATE (conf_char);
-      YYDSYMPRINTF ("Next token is", conf_token, &conf_lval, &conf_lloc);
+      YY_SYMBOL_PRINT ("Next token is", conf_token, &conf_lval, &conf_lloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -963,8 +1084,8 @@ conf_backup:
   if (conf_n == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", conf_tname[conf_token]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", conf_token, &conf_lval, &conf_lloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (conf_char != YYEOF)
@@ -1027,8 +1148,8 @@ conf_reduce:
 #line 103 "conf_parse.y"
     {
 		  if (conf_debug)
-		    fprintf(stderr, "sec_header1 = \"%s\"\n", conf_vsp[-2].strtype);
-		  header_section = conf_vsp[-2].strtype;
+		    fprintf(stderr, "sec_header1 = \"%s\"\n", (conf_vsp[-2].strtype));
+		  header_section = (conf_vsp[-2].strtype);
 		}
     break;
 
@@ -1036,8 +1157,8 @@ conf_reduce:
 #line 115 "conf_parse.y"
     {
 		  if (conf_debug)
-		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
-		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		    fprintf(stderr,"parse1: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
+		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
 		  if (retval != 0) {
 		    conf_error("syntax error");
 		    YYABORT;
@@ -1049,8 +1170,8 @@ conf_reduce:
 #line 125 "conf_parse.y"
     {
 		  if (conf_debug)
-		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
-		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		    fprintf(stderr,"parse2: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
+		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
 		  if (retval != 0) {
 		    conf_error("syntax error");
 		    YYABORT;
@@ -1062,8 +1183,8 @@ conf_reduce:
 #line 135 "conf_parse.y"
     {
 		  if (conf_debug)
-		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", conf_vsp[-3].strtype, conf_vsp[-1].strtype);
-		  retval = set_conf_kv(header_section, conf_vsp[-3].strtype, conf_vsp[-1].strtype);
+		    fprintf(stderr,"parse3: key=\"%s\", val=\"%s\"\n", (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
+		  retval = set_conf_kv(header_section, (conf_vsp[-3].strtype), (conf_vsp[-1].strtype));
 		  if (retval != 0) {
 		    conf_error("syntax error");
 		    YYABORT;
@@ -1072,10 +1193,11 @@ conf_reduce:
     break;
 
 
+      default: break;
     }
 
-/* Line 991 of yacc.c.  */
-#line 1078 "conf_parse.c"
+/* Line 1126 of yacc.c.  */
+#line 1201 "conf_parse.c"
 
   conf_vsp -= conf_len;
   conf_ssp -= conf_len;
@@ -1114,104 +1236,153 @@ conf_errlab:
 
       if (YYPACT_NINF < conf_n && conf_n < YYLAST)
 	{
-	  YYSIZE_T conf_size = 0;
 	  int conf_type = YYTRANSLATE (conf_char);
-	  char *conf_msg;
-	  int conf_x, conf_count;
+	  YYSIZE_T conf_size0 = conf_tnamerr (0, conf_tname[conf_type]);
+	  YYSIZE_T conf_size = conf_size0;
+	  YYSIZE_T conf_size1;
+	  int conf_size_overflow = 0;
+	  char *conf_msg = 0;
+#	  define YYERROR_VERBOSE_ARGS_MAXIMUM 5
+	  char const *conf_arg[YYERROR_VERBOSE_ARGS_MAXIMUM];
+	  int conf_x;
+
+#if 0
+	  /* This is so xgettext sees the translatable formats that are
+	     constructed on the fly.  */
+	  YY_("syntax error, unexpected %s");
+	  YY_("syntax error, unexpected %s, expecting %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
+#endif
+	  char *conf_fmt;
+	  char const *conf_f;
+	  static char const conf_unexpected[] = "syntax error, unexpected %s";
+	  static char const conf_expecting[] = ", expecting %s";
+	  static char const conf_or[] = " or %s";
+	  char conf_format[sizeof conf_unexpected
+			+ sizeof conf_expecting - 1
+			+ ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
+			   * (sizeof conf_or - 1))];
+	  char const *conf_prefix = conf_expecting;
 
-	  conf_count = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  for (conf_x = conf_n < 0 ? -conf_n : 0;
-	       conf_x < (int) (sizeof (conf_tname) / sizeof (char *)); conf_x++)
-	    if (conf_check[conf_x + conf_n] == conf_x && conf_x != YYTERROR)
-	      conf_size += conf_strlen (conf_tname[conf_x]) + 15, conf_count++;
-	  conf_size += conf_strlen ("syntax error, unexpected ") + 1;
-	  conf_size += conf_strlen (conf_tname[conf_type]);
-	  conf_msg = (char *) YYSTACK_ALLOC (conf_size);
-	  if (conf_msg != 0)
-	    {
-	      char *conf_p = conf_stpcpy (conf_msg, "syntax error, unexpected ");
-	      conf_p = conf_stpcpy (conf_p, conf_tname[conf_type]);
+	  int conf_xbegin = conf_n < 0 ? -conf_n : 0;
 
-	      if (conf_count < 5)
+	  /* Stay within bounds of both conf_check and conf_tname.  */
+	  int conf_checklim = YYLAST - conf_n;
+	  int conf_xend = conf_checklim < YYNTOKENS ? conf_checklim : YYNTOKENS;
+	  int conf_count = 1;
+
+	  conf_arg[0] = conf_tname[conf_type];
+	  conf_fmt = conf_stpcpy (conf_format, conf_unexpected);
+
+	  for (conf_x = conf_xbegin; conf_x < conf_xend; ++conf_x)
+	    if (conf_check[conf_x + conf_n] == conf_x && conf_x != YYTERROR)
+	      {
+		if (conf_count == YYERROR_VERBOSE_ARGS_MAXIMUM)
+		  {
+		    conf_count = 1;
+		    conf_size = conf_size0;
+		    conf_format[sizeof conf_unexpected - 1] = '\0';
+		    break;
+		  }
+		conf_arg[conf_count++] = conf_tname[conf_x];
+		conf_size1 = conf_size + conf_tnamerr (0, conf_tname[conf_x]);
+		conf_size_overflow |= conf_size1 < conf_size;
+		conf_size = conf_size1;
+		conf_fmt = conf_stpcpy (conf_fmt, conf_prefix);
+		conf_prefix = conf_or;
+	      }
+
+	  conf_f = YY_(conf_format);
+	  conf_size1 = conf_size + conf_strlen (conf_f);
+	  conf_size_overflow |= conf_size1 < conf_size;
+	  conf_size = conf_size1;
+
+	  if (!conf_size_overflow && conf_size <= YYSTACK_ALLOC_MAXIMUM)
+	    conf_msg = (char *) YYSTACK_ALLOC (conf_size);
+	  if (conf_msg)
+	    {
+	      /* Avoid sprintf, as that infringes on the user's name space.
+		 Don't have undefined behavior even if the translation
+		 produced a string with the wrong number of "%s"s.  */
+	      char *conf_p = conf_msg;
+	      int conf_i = 0;
+	      while ((*conf_p = *conf_f))
 		{
-		  conf_count = 0;
-		  for (conf_x = conf_n < 0 ? -conf_n : 0;
-		       conf_x < (int) (sizeof (conf_tname) / sizeof (char *));
-		       conf_x++)
-		    if (conf_check[conf_x + conf_n] == conf_x && conf_x != YYTERROR)
-		      {
-			const char *conf_q = ! conf_count ? ", expecting " : " or ";
-			conf_p = conf_stpcpy (conf_p, conf_q);
-			conf_p = conf_stpcpy (conf_p, conf_tname[conf_x]);
-			conf_count++;
-		      }
+		  if (*conf_p == '%' && conf_f[1] == 's' && conf_i < conf_count)
+		    {
+		      conf_p += conf_tnamerr (conf_p, conf_arg[conf_i++]);
+		      conf_f += 2;
+		    }
+		  else
+		    {
+		      conf_p++;
+		      conf_f++;
+		    }
 		}
 	      conf_error (conf_msg);
 	      YYSTACK_FREE (conf_msg);
 	    }
 	  else
-	    conf_error ("syntax error; also virtual memory exhausted");
+	    {
+	      conf_error (YY_("syntax error"));
+	      goto conf_exhaustedlab;
+	    }
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	conf_error ("syntax error");
+	conf_error (YY_("syntax error"));
     }
 
 
 
   if (conf_errstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
-      /* Return failure if at end of input.  */
-      if (conf_char == YYEOF)
+      if (conf_char <= YYEOF)
         {
-	  /* Pop the error token.  */
-          YYPOPSTACK;
-	  /* Pop the rest of the stack.  */
-	  while (conf_ss < conf_ssp)
-	    {
-	      YYDSYMPRINTF ("Error: popping", conf_stos[*conf_ssp], conf_vsp, conf_lsp);
-	      conf_destruct (conf_stos[*conf_ssp], conf_vsp);
-	      YYPOPSTACK;
-	    }
-	  YYABORT;
+	  /* Return failure if at end of input.  */
+	  if (conf_char == YYEOF)
+	    YYABORT;
         }
-
-      YYDSYMPRINTF ("Error: discarding", conf_token, &conf_lval, &conf_lloc);
-      conf_destruct (conf_token, &conf_lval);
-      conf_char = YYEMPTY;
-
+      else
+	{
+	  conf_destruct ("Error: discarding", conf_token, &conf_lval);
+	  conf_char = YYEMPTY;
+	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
-  goto conf_errlab2;
+  goto conf_errlab1;
 
 
-/*----------------------------------------------------.
-| conf_errlab1 -- error raised explicitly by an action.  |
-`----------------------------------------------------*/
+/*---------------------------------------------------.
+| conf_errorlab -- error raised explicitly by YYERROR.  |
+`---------------------------------------------------*/
+conf_errorlab:
+
+  /* Pacify compilers like GCC when the user code never invokes
+     YYERROR and the label conf_errorlab therefore never appears in user
+     code.  */
+  if (0)
+     goto conf_errorlab;
+
+conf_vsp -= conf_len;
+  conf_ssp -= conf_len;
+  conf_state = *conf_ssp;
+  goto conf_errlab1;
+
+
+/*-------------------------------------------------------------.
+| conf_errlab1 -- common code for both syntax error and YYERROR.  |
+`-------------------------------------------------------------*/
 conf_errlab1:
-
-  /* Suppress GCC warning that conf_errlab1 is unused when no action
-     invokes YYERROR.  */
-#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__) \
-    && !defined __cplusplus
-  __attribute__ ((__unused__))
-#endif
-
-
-  goto conf_errlab2;
-
-
-/*---------------------------------------------------------------.
-| conf_errlab2 -- pop states until the error token can be shifted.  |
-`---------------------------------------------------------------*/
-conf_errlab2:
   conf_errstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1232,22 +1403,22 @@ conf_errlab2:
       if (conf_ssp == conf_ss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", conf_stos[*conf_ssp], conf_vsp, conf_lsp);
-      conf_destruct (conf_stos[conf_state], conf_vsp);
-      conf_vsp--;
-      conf_state = *--conf_ssp;
 
+      conf_destruct ("Error: popping", conf_stos[conf_state], conf_vsp);
+      YYPOPSTACK;
+      conf_state = *conf_ssp;
       YY_STACK_PRINT (conf_ss, conf_ssp);
     }
 
   if (conf_n == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++conf_vsp = conf_lval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", conf_stos[conf_n], conf_vsp, conf_lsp);
+
   conf_state = conf_n;
   goto conf_newstate;
 
@@ -1267,16 +1438,25 @@ conf_abortlab:
   goto conf_return;
 
 #ifndef conf_overflow
-/*----------------------------------------------.
-| conf_overflowlab -- parser overflow comes here.  |
-`----------------------------------------------*/
-conf_overflowlab:
-  conf_error ("parser stack overflow");
+/*-------------------------------------------------.
+| conf_exhaustedlab -- memory exhaustion comes here.  |
+`-------------------------------------------------*/
+conf_exhaustedlab:
+  conf_error (YY_("memory exhausted"));
   conf_result = 2;
   /* Fall through.  */
 #endif
 
 conf_return:
+  if (conf_char != YYEOF && conf_char != YYEMPTY)
+     conf_destruct ("Cleanup: discarding lookahead",
+		 conf_token, &conf_lval);
+  while (conf_ssp != conf_ss)
+    {
+      conf_destruct ("Cleanup: popping",
+		  conf_stos[*conf_ssp], conf_vsp);
+      YYPOPSTACK;
+    }
 #ifndef conf_overflow
   if (conf_ss != conf_ssa)
     YYSTACK_FREE (conf_ss);
