@@ -8,12 +8,12 @@
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.6.11.4-21.7-default"
+#define HOST_OS_VERSION "2.6.16-rc6-git1-4-default"
 #define HOST_ARCH "i386"
-#define DISTRO_NAME "suse9.3"
-#define HOST_NAME "a-suse93"
+#define DISTRO_NAME "suse10.1"
+#define HOST_NAME "dhcp6"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:28:18 EDT 2006"
+#define CONFIG_DATE "Wed Mar 22 21:29:29 EST 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -32,9 +32,9 @@
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
-#include <stdlib.h>
+void exit (int);
 #endif
-#define HOST_HEADER_VERSION "2.6.9"
+#define HOST_HEADER_VERSION "2.6.16"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
@@ -290,12 +290,19 @@
 #define HAVE_NFS_ARGS_T_VERSION 1
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_SUN 1
+#define HAVE_WAITPID 1
 #define HAVE_MAP_EXEC 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_NIS_DOMAIN_OF 1
 #define HAVE_MAP_NISPLUS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CDFS 1
@@ -319,7 +326,7 @@
 #define HAVE_AMU_FS_UNION 1
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
-#define MOUNT_TYPE_UFS "ext2"
+#define MOUNT_TYPE_UFS "ext3"
 #define MOUNT_TYPE_XFS "xfs"
 #define MOUNT_TYPE_EFS "efs"
 #define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
@@ -330,7 +337,7 @@
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs"
-#define MNTTAB_TYPE_UFS "ext2"
+#define MNTTAB_TYPE_UFS "ext3"
 #define MNTTAB_TYPE_XFS "xfs"
 #define MNTTAB_TYPE_EFS "efs"
 #define MNTTAB_TYPE_CDFS "iso9660"
